@@ -84,7 +84,7 @@
 #define BALOO_CORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef BALOO_CORE_NO_DEPRECATED
-#  define BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57300
 #endif
 #ifdef BALOO_CORE_NO_DEPRECATED_WARNINGS
 #  define BALOO_CORE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define BALOO_CORE_DEPRECATED_WARNINGS_SINCE BALOO_CORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define BALOO_CORE_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define BALOO_CORE_DEPRECATED_WARNINGS_SINCE 0x57300
 #  endif
 #endif
 
